==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/GeographicContourLineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicXYTriangulatingSeriesView } from "./GeographicXYTriangulatingSeriesView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterContourSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, typeCast, markDep } from "igniteui-webcomponents-core";
import { GeographicXYTriangulatingSeries } from "./GeographicXYTriangulatingSeries";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { ValueBrushScale } from "igniteui-webcomponents-charts";
import { ContourValueResolver } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicContourLineSeriesView = /*@__PURE__*/ (() => {
    class GeographicContourLineSeriesView extends GeographicXYTriangulatingSeriesView {
        constructor(a) {
            super(a);
            this.cp = null;
            this.cp = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.cp.iv = Defaults.m;
            }
        }
        b5() {
            super.b5();
            if (this.cp.t5 != null) {
                this.cp.ux.v0 = this.cp.u0;
                this.cp.ux.wa = this.cp.u4;
            }
        }
        cq() {
            if (this.cp.ux != null) {
                this.cp.ux.v0 = this.cp.u0;
            }
        }
        cr() {
            if (this.cp.ux != null) {
                this.cp.ux.wa = this.cp.u4;
            }
        }
    }
    GeographicContourLineSeriesView.$t = /*@__PURE__*/ markType(GeographicContourLineSeriesView, 'GeographicContourLineSeriesView', GeographicXYTriangulatingSeriesView.$);
    return GeographicContourLineSeriesView;
})();
/**
 * @hidden
 */
export let GeographicContourLineSeries = /*@__PURE__*/ (() => {
    class GeographicContourLineSeries extends GeographicXYTriangulatingSeries {
        bc() {
            return new GeographicContourLineSeries();
        }
        get_ex() {
            return true;
        }
        constructor() {
            super();
            this.triangulationStatusChanged = null;
            this.ab = GeographicContourLineSeries.$;
        }
        ua() {
            super.ua();
        }
        t4() {
            this.ux = new ScatterContourSeries();
            let a = this.ux;
            a.triangulationStatusChanged = delegateCombine(a.triangulationStatusChanged, runOn(this, this.u7));
            let b = this.ux;
            b.propertyUpdated = delegateCombine(b.propertyUpdated, runOn(this, this.u8));
            return this.ux;
        }
        u7(a, b) {
            if (this.triangulationStatusChanged != null) {
                this.triangulationStatusChanged(this, b);
            }
        }
        u8(a, b) {
            let c = typeCast(ScatterContourSeries.$, this.t5);
            if (c == null) {
                return;
            }
            if (b.propertyName == "ActualFillScale") {
                this.uz = c.vz;
            }
        }
        qf() {
            super.qf();
        }
        cd() {
            return new GeographicContourLineSeriesView(this);
        }
        o2(a) {
            super.o2(a);
            this.u1 = a;
        }
        pa(a, b, c, d) {
            super.pa(a, b, c, d);
            switch (b) {
                case GeographicContourLineSeries.$$p[1]:
                    this.u1.cq();
                    break;
                case GeographicContourLineSeries.$$p[2]:
                    this.u1.cr();
                    break;
                case GeographicContourLineSeries.$$p[3]:
                    this.ux.vx = this.uw;
                    break;
                case "DashArray":
                    this.ux.s9 = this.s9;
                    break;
                case "DashCap":
                    this.ux.ta = this.ta;
                    break;
                case "MiterLimit":
                    this.ux.im = this.im;
                    break;
                case "LineJoin":
                    this.ux.tc = this.tc;
                    break;
            }
        }
    }
    GeographicContourLineSeries.$t = /*@__PURE__*/ markType(GeographicContourLineSeries, 'GeographicContourLineSeries', GeographicXYTriangulatingSeries.$);
    GeographicContourLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicContourLineSeries, 'raisePropertyChanged', ['ActualFillScale:uz:u9', [ValueBrushScale.$, null], 'FillScale:u0:va', [ValueBrushScale.$, null], 'ValueMemberPath:u4:vb', [2, "value"], 'ValueResolver:uw:vc', [ContourValueResolver.$, null]]);
    return GeographicContourLineSeries;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/GeographicContourLineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicXYTriangulatingSeriesView } from "./GeographicXYTriangulatingSeriesView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterContourSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, typeCast, markDep } from "igniteui-webcomponents-core";
import { GeographicXYTriangulatingSeries } from "./GeographicXYTriangulatingSeries";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { ValueBrushScale } from "igniteui-webcomponents-charts";
import { ContourValueResolver } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicContourLineSeriesView = /*@__PURE__*/ (() => {
    class GeographicContourLineSeriesView extends GeographicXYTriangulatingSeriesView {
        constructor(a) {
            super(a);
            this.ct = null;
            this.ct = a;
        }
        ax() {
            super.ax();
            if (!this.r) {
                this.ct.jp = Defaults.m;
            }
        }
        b9() {
            super.b9();
            if (this.ct.w2 != null) {
                this.ct.xu.yx = this.ct.xx;
                this.ct.xu.y7 = this.ct.x1;
            }
        }
        cu() {
            if (this.ct.xu != null) {
                this.ct.xu.yx = this.ct.xx;
            }
        }
        cv() {
            if (this.ct.xu != null) {
                this.ct.xu.y7 = this.ct.x1;
            }
        }
    }
    GeographicContourLineSeriesView.$t = /*@__PURE__*/ markType(GeographicContourLineSeriesView, 'GeographicContourLineSeriesView', GeographicXYTriangulatingSeriesView.$);
    return GeographicContourLineSeriesView;
})();
/**
 * @hidden
 */
export let GeographicContourLineSeries = /*@__PURE__*/ (() => {
    class GeographicContourLineSeries extends GeographicXYTriangulatingSeries {
        bk() {
            return new GeographicContourLineSeries();
        }
        get_fj() {
            return true;
        }
        constructor() {
            super();
            this.triangulationStatusChanged = null;
            this.ab = GeographicContourLineSeries.$;
        }
        w7(a, b) {
            super.w7(a, b);
        }
        w1() {
            this.xu = new ScatterContourSeries();
            let a = this.xu;
            a.triangulationStatusChanged = delegateCombine(a.triangulationStatusChanged, runOn(this, this.x4));
            let b = this.xu;
            b.propertyUpdated = delegateCombine(b.propertyUpdated, runOn(this, this.x5));
            return this.xu;
        }
        x4(a, b) {
            if (this.triangulationStatusChanged != null) {
                this.triangulationStatusChanged(this, b);
            }
        }
        x5(a, b) {
            let c = typeCast(ScatterContourSeries.$, this.w2);
            if (c == null) {
                return;
            }
            if (b.propertyName == "ActualFillScale") {
                this.xw = c.yw;
            }
        }
        sj() {
            super.sj();
        }
        ct() {
            return new GeographicContourLineSeriesView(this);
        }
        q1(a) {
            super.q1(a);
            this.xy = a;
        }
        ra(a, b, c, d) {
            super.ra(a, b, c, d);
            switch (b) {
                case GeographicContourLineSeries.$$p[1]:
                    this.xy.cu();
                    break;
                case GeographicContourLineSeries.$$p[2]:
                    this.xy.cv();
                    break;
                case GeographicContourLineSeries.$$p[3]:
                    this.xu.yu = this.xt;
                    break;
                case "DashArray":
                    this.xu.v4 = this.v4;
                    break;
                case "DashCap":
                    this.xu.v5 = this.v5;
                    break;
                case "MiterLimit":
                    this.xu.jh = this.jh;
                    break;
                case "LineJoin":
                    this.xu.v7 = this.v7;
                    break;
            }
        }
    }
    GeographicContourLineSeries.$t = /*@__PURE__*/ markType(GeographicContourLineSeries, 'GeographicContourLineSeries', GeographicXYTriangulatingSeries.$);
    GeographicContourLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicContourLineSeries, 'raisePropertyChanged', ['ActualFillScale:xw:x6', [ValueBrushScale.$, null], 'FillScale:xx:x7', [ValueBrushScale.$, null], 'ValueMemberPath:x1:x8', [2, "value"], 'ValueResolver:xt:x9', [ContourValueResolver.$, null]]);
    return GeographicContourLineSeries;
})();
